
#include <proto/exec.h>
#include <proto/dos.h>
#include <proto/graphics.h>
#include <proto/intuition.h>

#include <stdio.h>
#include <string.h>

int main (void)

{
long width  = 640;
long height = 480;
long depth  = 24;
ULONG modeid;
struct Screen *scr;
struct Window *win;
struct IntuiMessage *imsg;
struct RastPort *rp;
BOOL cont;
char buffer[80];

modeid = BestModeID (
		BIDTAG_NominalWidth,width,
		BIDTAG_NominalHeight,height,
		BIDTAG_Depth,depth,
		TAG_END);

if (modeid == INVALID_ID)
	{
	Printf ("no appropiate screen mode available\n");
	return (RETURN_ERROR);
	}

scr = OpenScreenTags (NULL,
		SA_LikeWorkbench,TRUE,
		SA_DisplayID,modeid,
		TAG_END);

if (scr == NULL)
	{
	Printf ("cannot open screen\n");
	return (RETURN_ERROR);
	}

win = OpenWindowTags (NULL,
		WA_CustomScreen,scr,
		WA_Flags,WFLG_CLOSEGADGET | WFLG_DRAGBAR | WFLG_DEPTHGADGET | WFLG_SIZEGADGET | WFLG_ACTIVATE | WFLG_NOCAREREFRESH,
		WA_IDCMP,IDCMP_CLOSEWINDOW | IDCMP_VANILLAKEY,
		WA_MinWidth,200,
		WA_MinHeight,100,
		TAG_END);

if (win == NULL)
	{
	Printf ("cannot open window\n");
	CloseScreen (scr);
	return (RETURN_ERROR);
	}

rp = win->RPort;
SetABPenDrMd (rp,1,0,JAM2);
sprintf (buffer,"Width  = %4ld",scr->Width);
Move (rp,20,40);
Text (rp,buffer,strlen(buffer));
sprintf (buffer,"Height = %4ld",scr->Height);
Move (rp,20,60);
Text (rp,buffer,strlen(buffer));
sprintf (buffer,"Depth  = %4ld",GetBitMapAttr(scr->RastPort.BitMap,BMA_DEPTH));
Move (rp,20,80);
Text (rp,buffer,strlen(buffer));

cont = TRUE;
do	{
	if (Wait ((1L << win->UserPort->mp_SigBit) | SIGBREAKF_CTRL_C) & SIGBREAKF_CTRL_C)
		cont = FALSE;

	while (imsg = (struct IntuiMessage *) GetMsg (win->UserPort))
		{
		switch (imsg->Class)
			{
		case IDCMP_VANILLAKEY:
			if (imsg->Code == 0x1b) /* Esc */
				cont = FALSE;
			break;
		case IDCMP_CLOSEWINDOW:
			cont = FALSE;
			break;
			}
		ReplyMsg ((struct Message *) imsg);
		}
	}
while (cont);

CloseWindow (win);
CloseScreen (scr);

return (RETURN_OK);
}
